

.. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0:

spectral_frame-1.0.0: Represents a spectral frame.
==================================================

:soft:`Type:` object :soft:`and` :doc:`frame-1.0.0 <frame-1.0.0>`.

Represents a spectral frame.




:category:`All of:`



  .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/0:

  :entry:`0`

  :soft:`Type:` object.

  

  

  :category:`Properties:`



    .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/0/properties/reference_position:

    :entry:`reference_position`

    :soft:`Type:` any :soft:`from` ["geocenter", "barycenter", "heliocenter"].

    

    The position of the reference frame.
    

    :soft:`Default:` "geocenter"



    .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/0/properties/axes_names:

    :entry:`axes_names`

    :soft:`Type:` any.

    

    



    .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/0/properties/axes_order:

    :entry:`axes_order`

    :soft:`Type:` any.

    

    



    .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/0/properties/unit:

    :entry:`unit`

    :soft:`Type:` any.

    

    



  .. _http://stsci.edu/schemas/gwcs/spectral_frame-1.0.0/allOf/1:

  :entry:`1`

  :soft:`Type:` :doc:`frame-1.0.0 <frame-1.0.0>`.

  

  

